**Example 1: 导出漏洞防御插件事件**



Input: 

```
tccli cwp ExportVulDefencePluginEvent --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "xx",
        "TaskId": "12"
    }
}
```

